@@ -33,14 +33,15 @@ class LatexReference;
 class LatexCompleter : public QObject  {
 	Q_OBJECT
 public:
-    enum CompletionFlag { CF_FORCE_VISIBLE_LIST = 1, CF_NORMAL_TEXT = 2, CF_FORCE_REF = 4, CF_OVERRIDEN_BACKSLASH=8,CF_FORCE_GRAPHIC = 16, CF_FORCE_CITE = 32, CF_FORCE_PACKAGE = 64, CF_FORCE_KEYVAL = 128, CF_FORCE_SPECIALOPTION = 256};
+    enum CompletionFlag { CF_FORCE_VISIBLE_LIST = 1, CF_NORMAL_TEXT = 2, CF_FORCE_REF = 4, CF_OVERRIDEN_BACKSLASH=8,CF_FORCE_GRAPHIC = 16, CF_FORCE_CITE = 32, CF_FORCE_PACKAGE = 64, CF_FORCE_KEYVAL = 128, CF_FORCE_SPECIALOPTION = 256, CF_FORCE_LENGTH = 512,CF_FORCE_REFLIST=1024};
 	Q_DECLARE_FLAGS(CompletionFlags, CompletionFlag);
 	
 	LatexCompleter(const LatexParser& latexParser, QObject *p = 0);
 	virtual ~LatexCompleter();
 	
 	void complete(QEditor *newEditor, const CompletionFlags &flags);
-	void setAdditionalWords(const QSet<QString> &newwords, CompletionType completionType=CT_COMMANDS);
+    void setAdditionalWords(const CodeSnippetList &newwords, CompletionType completionType=CT_COMMANDS);
+    void setAdditionalWords(const QSet<QString> &newwords, CompletionType completionType);
     void setKeyValWords(const QString &name,const QSet<QString> &newwords);
     void setContextWords(const QSet<QString> &newwords,const QString &context);
 	void updateAbbreviations();
@@ -75,10 +76,13 @@ public:
 	void setTab(int index);
 	
 	void insertText(QString txt);
+
+    void showTooltip(QString topic);
 signals:
 	void setDirectoryForCompletion(QString fn);
 	void searchBibtexSection(QString file,QString bibId);
     void showImagePreview(QString fn);
+    void showPreview(QString text);
 private:
 	friend class CompleterInputBinding;
 	friend class CompletionListModel;
@@ -97,7 +101,7 @@ private:
 	
 	bool editorAutoCloseChars;
 	
-	void filterList(QString word,int showMostUsed=-1);
+    void filterList(QString word, int showMostUsed=-1);
 	bool acceptChar(QChar c,int pos);
 	void adjustWidget();
 	
@@ -109,14 +113,13 @@ private:
     bool forcedPackage;
     bool forcedKeyval;
     bool forcedSpecialOption;
+    bool forcedLength;
     bool startedFromTriggerKey;
 	QString workingDir;
 	
 	QPoint lastPos;
 	bibtexReader *bibReader;
 	
-	void showTooltip(QString topic);
-
 private slots:
 	void cursorPositionChanged();
 	void selectionChanged(const QModelIndex & index);
