@@ -10,7 +10,8 @@ class LatexEditorViewConfig
 public:
 	bool parenmatch, parenComplete;
 	bool autoindent, weakindent;
-	bool indentWithSpaces;
+	bool replaceIndentTabs;
+	bool replaceTextTabs;
 	bool showWhitespace;
 	int tabStop;
 	int showlinemultiples;
@@ -40,10 +41,11 @@ public:
 	bool texdocHelpInInternalViewer;
 	bool silentReload;
 	
-	bool autoInsertLRM, visualColumnMode;
+	bool autoInsertLRM, visualColumnMode, switchLanguagesDirection, switchLanguagesMath;
 
 	bool overwriteOpeningBracketFollowedByPlaceholder;
 	bool overwriteClosingBracketFollowingPlaceholder;
+	bool doubleClickSelectionIncludeLeadingBackslash;
 	int contextMenuSpellcheckingEntryLocation;
 	int contextMenuKeyboardModifiers;  // actually this is a Qt::KeyboardModifiers flag (but we don't want to import the whole qt namespace here)
 
