@@ -16,67 +16,44 @@
 #include "texmaker.h"
 #include "smallUsefulFunctions.h"
 #include "debughelper.h"
-
-#if QT_VERSION >= 0x040400
 #include <qtsingleapplication.h>
-#else
-#include "dsingleapplication.h"
-#endif
-
 #include <QSplashScreen>
+
 #ifdef Q_OS_WIN32
 #include "windows.h"
 typedef BOOL (WINAPI * AllowSetForegroundWindowFunc)(DWORD);
 #endif
 
-
-#if QT_VERSION >= 0x040400
-class TexmakerApp : public QtSingleApplication {
-#else
-class TexmakerApp : public QApplication {
-#endif
+class TexstudioApp : public QtSingleApplication {
 protected:
 	bool event(QEvent *event);
 public:
 	bool initialized;
 	QString delayedFileLoad;
 	Texmaker *mw;  // Moved from private:
-	TexmakerApp(int & argc, char ** argv);
-    #if QT_VERSION >= 0x040400
-	TexmakerApp(QString &id,int & argc, char ** argv);
-    #endif
-	~TexmakerApp();
+	TexstudioApp(int & argc, char ** argv);
+	TexstudioApp(QString &id, int & argc, char ** argv);
+	~TexstudioApp();
 	void init(QStringList &cmdLine);   // This function does all the initialization instead of the constructor.
-/*really slow global event logging:
+	/*really slow global event logging:
 	bool notify(QObject* obj, QEvent* event){
 		qWarning(qPrintable(QString("%1 obj %2 named %3 typed %4 child of %5 received %6").arg(QTime::currentTime().toString("HH:mm:ss:zzz")).arg((long)obj,8,16).arg(obj->objectName()).arg(obj->metaObject()->className()).arg(obj->parent()?obj->parent()->metaObject()->className():"").arg(event->type())));
 		return QApplication::notify(obj,event);
-	}//*/
+	}
+	*/
 };
 
-
-#if QT_VERSION >= 0x040400
-TexmakerApp::TexmakerApp(int & argc, char ** argv) : QtSingleApplication(argc, argv) {
+TexstudioApp::TexstudioApp(int & argc, char ** argv) : QtSingleApplication(argc, argv) {
 	mw = 0;
 	initialized=false;
 }
 
-TexmakerApp::TexmakerApp(QString &id,int & argc, char ** argv) : QtSingleApplication(id,argc, argv) {
+TexstudioApp::TexstudioApp(QString &id,int & argc, char ** argv) : QtSingleApplication(id,argc, argv) {
 	mw = 0;
 	initialized=false;
 }
-#else
-TexmakerApp::TexmakerApp(int & argc, char ** argv) : QApplication(argc, argv) {
-	mw = 0;
-	initialized=false;
-}
-#endif
 
-
-
-
-
-void TexmakerApp::init(QStringList &cmdLine) {
+void TexstudioApp::init(QStringList &cmdLine) {
 	QPixmap pixmap(":/images/splash.png");
 	QSplashScreen *splash = new QSplashScreen(pixmap);
 	splash->show();
@@ -94,11 +71,11 @@ void TexmakerApp::init(QStringList &cmdLine) {
 	mw->startupCompleted();
 }
 
-TexmakerApp::~TexmakerApp() {
+TexstudioApp::~TexstudioApp() {
 	if (mw) delete mw;
 }
 
-bool TexmakerApp::event(QEvent * event) {
+bool TexstudioApp::event(QEvent * event) {
 	if (event->type() == QEvent::FileOpen) {
 		QFileOpenEvent *oe = static_cast<QFileOpenEvent *>(event);
 		if (initialized) mw->load(oe->file());
@@ -109,32 +86,24 @@ bool TexmakerApp::event(QEvent * event) {
 	return QApplication::event(event);
 }
 
-int main(int argc, char ** argv) {
-// This is a dummy constructor so that the programs loads fast.
-	QStringList environment = QProcess::systemEnvironment();
-	QString user=environment.filter(QRegExp("^USERNAME=|^USER=",Qt::CaseInsensitive)).first();
-
-	if(!user.isEmpty()){
-		int l=user.indexOf("=",0);
-		user="_"+user.right(user.length()-l-1);
+QString generateAppId() {
+	QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
+	QString user = env.value("USER");
+	if (user.isEmpty()) {
+		user = env.value("USERNAME");
 	}
-	user=TEXSTUDIO+user;
-#if QT_VERSION >= 0x040400
-	TexmakerApp a(user,argc, argv);
-#else
-    TexmakerApp a(argc, argv);
-	DSingleApplication instance(user);
-#endif
-	bool startAlways=false;
-	QStringList args = QCoreApplication::arguments();
+	return QString("%1_%2").arg(TEXSTUDIO).arg(user);
+}
+
+QStringList parseArguments(const QStringList &args, bool &outStartAlways) {
 	QStringList cmdLine;
-	for (int i = 1; i < args.count(); ++i) {
+	for (int i=1; i<args.count(); ++i) {
 		QString cmdArgument =  args[i];
 
 		if (cmdArgument.startsWith('-')) {
 			// various commands
 			if (cmdArgument == "--start-always")
-				startAlways = true;
+				outStartAlways = true;
 			else if ((cmdArgument == "-line" || cmdArgument == "--line") && (++i < args.count()))
 				cmdLine << "--line" << args[i];
 			else if ((cmdArgument == "-page" || cmdArgument == "--page") && (++i < args.count()))
@@ -144,40 +113,36 @@ int main(int argc, char ** argv) {
 			else if (cmdArgument == "--ini-file" && (++i < args.count()))
 				ConfigManager::iniFileOverride = args[i];
 			else if (cmdArgument.startsWith("-"))
-				cmdLine << cmdArgument;			
+				cmdLine << cmdArgument;
 		} else
 			cmdLine << QFileInfo(cmdArgument).absoluteFilePath();
 	}
+	return cmdLine;
+}
 
-	if (!startAlways)
-#if QT_VERSION >= 0x040400
+int main(int argc, char ** argv) {
+	QString appId = generateAppId();
+	// This is a dummy constructor so that the programs loads fast.
+	TexstudioApp a(appId, argc, argv);
+	bool startAlways = false;
+	QStringList cmdLine = parseArguments(QCoreApplication::arguments(), startAlways);
+
+	if (!startAlways) {
 		if (a.isRunning()) {
-#else
-		if (instance.isRunning()) {
-#endif
 #ifdef Q_OS_WIN32
-			AllowSetForegroundWindowFunc asfw = (AllowSetForegroundWindowFunc)GetProcAddress(GetModuleHandleA("user32.dll"),"AllowSetForegroundWindow");
+			AllowSetForegroundWindowFunc asfw = (AllowSetForegroundWindowFunc) GetProcAddress(GetModuleHandleA("user32.dll"), "AllowSetForegroundWindow");
 			if (asfw) asfw(/*ASFW_ANY*/(DWORD)(-1));
 #endif
-
-#if QT_VERSION >= 0x040400
 			a.sendMessage(cmdLine.join("#!#"));
-#else
-			instance.sendMessage(cmdLine.join("#!#"));
-#endif
 			return 0;
 		}
+	}
 
 	a.setApplicationName( TEXSTUDIO );
 	a.init(cmdLine); // Initialization takes place only if there is no other instance running.
 
-#if QT_VERSION >= 0x040400
 	QObject::connect(&a, SIGNAL(messageReceived(const QString &)),
-					 a.mw,   SLOT(onOtherInstanceMessage(const QString &)));
-#else
-	QObject::connect(&instance, SIGNAL(messageReceived(const QString &)),
-					 a.mw,   SLOT(onOtherInstanceMessage(const QString &)));
-#endif
+					 a.mw, SLOT(onOtherInstanceMessage(const QString &)));
 
 	try {
 		return a.exec();
