@@ -82,7 +82,7 @@ public:
 	enum Error {NoError, FileOpenFailed, PopplerError, PopplerErrorBadAlloc, PopplerErrorException, FileLocked, FileIncomplete };
 
 	QPixmap renderToImage(int pageNr,QObject *obj,const char *rec,double xres=72.0, double yres=72.0, int x=-1, int y=-1, int w=-1, int h=-1,bool cache=true,bool priority=false,Poppler::Page::Rotation rotate=Poppler::Page::Rotate0);
-	QSharedPointer<Poppler::Document> loadDocument(const QString& fileName, Error &error, bool foreceLoad=false);
+	QSharedPointer<Poppler::Document> loadDocument(const QString& fileName, Error &error, const QString& userPasswordStr,  bool foreceLoad=false);
 	void stopRendering();
 	void setCacheSize(int megabyte);
 	void fillCache(int pg=-1);
