@@ -70,6 +70,9 @@ class QCE_EXPORT QDocumentLine
 			STACK_ENVIRONMENT_COOKIE = 1,
 			DIFF_LIST_COOCKIE = 2,
 			UNCLOSED_ENVIRONMENT_COOKIE = 3,
+            LEXER_COOKIE = 4,
+            LEXER_REMAINDER_COOKIE = 5,
+            LEXER_RAW_COOKIE = 6,
 			PICTURE_COOKIE = 42,
 			PICTURE_COOKIE_DRAWING_POS = 43,
 			GRAMMAR_ERROR_COOKIE = 44
