@@ -3,7 +3,54 @@
 #include "qdocumentsearch.h"
 #include "smallUsefulFunctions.h"
 
-SearchResultModel::SearchResultModel(QObject * parent): QAbstractItemModel(parent), mIsWord(false), mIsCaseSensitive(false), mIsRegExp(false)
+const int SearchResultModel::LineNumberRole = Qt::UserRole;
+
+/* *** internal id (iid) semantics ***
+ * the internal id associates QModelIndex with the internal data structure. The iid is structured as followed
+ *
+ * < search index >  < line index >
+ * 00000000 00000000 00000000 00000000
+ * 
+ * - The upper 16 bits encode the search (i.e. a top-level group):
+ *     m_seaches[i] maps to (i + 1) * (1 << 16)
+ * - Bit 16 (1<<15) is a flag indcating that the item is a result entry within a search
+ * - Bits 1-15 indicate the position of the result entry within the search
+ * 
+ * Example:
+ *  * tree structure *   ** iid **     * internal data *
+ *  Search in file A     0x00010000    searches[0]
+ *    Result entry a0    0x00018000    searches[0].lines[0]
+ *    Result entry a1    0x00018001    searches[0].lines[1]
+ *  Search in file B     0x00020000    seraches[1]
+ *    Result entry a0    0x00018000    searches[1].lines[0]
+ *    Result entry a1    0x00018001    searches[1].lines[1]
+ */
+
+#define RESULT_ENTRY_FLAG (1<<15)
+#define SEARCH_MASK 0xFFFF0000
+
+bool iidIsResultEntry(quint32 iid) {
+	return iid & RESULT_ENTRY_FLAG;
+}
+
+quint32 makeResultEntryIid(quint32 searchIid, int row) {
+	return searchIid + RESULT_ENTRY_FLAG + row;
+}
+
+quint32 searchIid(quint32 iid) {
+	return iid & SEARCH_MASK;
+}
+
+int searchIndexFromIid(quint32 iid) {
+	return int(iid >> 16) - 1;
+}
+
+quint32 iidFromSearchIndex(int searchIndex) {
+	return (searchIndex + 1) * (1 << 16);
+}
+
+
+SearchResultModel::SearchResultModel(QObject * parent): QAbstractItemModel(parent), mIsWord(false), mIsCaseSensitive(false), mIsRegExp(false), mAllowPartialSelection(true)
 {
 	m_searches.clear();
 	mExpression.clear();
@@ -17,7 +64,6 @@ void SearchResultModel::addSearch(const SearchInfo& search){
 #else
     beginResetModel();
 #endif
-
     m_searches.append(search);
     int lineNumber = 0;
     m_searches.last().lineNumberHints.clear();
@@ -44,6 +90,7 @@ void SearchResultModel::clear(){
 
     m_searches.clear();
 	mExpression.clear();
+	mAllowPartialSelection = true;
 
 #if QT_VERSION<0x050000
     reset();
@@ -54,11 +101,20 @@ void SearchResultModel::clear(){
 }
 
 void SearchResultModel::removeSearch(const QDocument* doc){
+	return;
+	// TODO: currently unused, also it requires beginResetModel() or similar
 	for (int i=m_searches.size()-1;i>=0;i--)
 		if (m_searches[i].doc == doc) 
 			m_searches.removeAt(i);
-	if(m_searches.isEmpty()) mExpression.clear();
 }
+
+void SearchResultModel::removeAllSearches()
+{
+	beginResetModel();
+	m_searches.clear();
+	endResetModel();
+}
+
 int SearchResultModel::columnCount(const QModelIndex & parent) const {
 	return parent.isValid()?1:1;
 }
@@ -68,84 +124,96 @@ int SearchResultModel::rowCount(const QModelIndex &parent) const {
 		return m_searches.size();
 	}else{
 		int i=parent.row();
-		if(i<m_searches.size()&&((parent.internalId()&(1<<15))==0)){
+		if (i<m_searches.size() && !iidIsResultEntry(parent.internalId())) {
 			return qMin(m_searches[i].lines.size(),1000); // maximum search results limited
 		} else return 0;
 	}
 }
+
 QModelIndex SearchResultModel::index(int row, int column, const QModelIndex &parent)
 const
 {
 	if(parent.isValid()){
-		int i=(parent.internalId()&0xFFFF0000)+(1<<15)+row;
-		return createIndex(row,column,i);
+		return createIndex(row, column, makeResultEntryIid(parent.internalId(), row));
 	}else{
-		return createIndex(row,column,(row+1)*(1<<16));
+		return createIndex(row, column, iidFromSearchIndex(row));
 	}
 }
 
 QModelIndex SearchResultModel::parent(const QModelIndex &index)
 const
 {
-	quint32 i=index.internalId();
-	if((i&(1<<15))>0){
-		return createIndex(int(i>>16)-1,0,i&0xFFFF0000);
-	}else return QModelIndex();
+	quint32 iid = index.internalId();
+	if (iidIsResultEntry(iid)) {
+		return createIndex(searchIndexFromIid(iid), 0, searchIid(iid));
+	} else return QModelIndex();
+}
+
+QVariant SearchResultModel::dataForResultEntry(const SearchInfo &search, int lineIndex, int role) const {
+	if (!search.doc) return QVariant();
+	bool lineIndexValid = (lineIndex >= 0 && lineIndex < search.lines.size() && lineIndex < search.lineNumberHints.size());
+	switch (role) {
+	case Qt::CheckStateRole:
+        if (!lineIndexValid) return QVariant();
+		return (search.checked.value(lineIndex, true) ? Qt::Checked : Qt::Unchecked);
+	case LineNumberRole:
+	{
+        if (!lineIndexValid) return QVariant();
+		int lineNo = search.doc->indexOf(search.lines[lineIndex], search.lineNumberHints[lineIndex]);
+		search.lineNumberHints[lineIndex] = lineNo;
+		if (lineNo < 0) return 0;
+		return lineNo+1;  // internal line number is 0-based
+	}
+	case Qt::DisplayRole:
+	case Qt::ToolTipRole:
+		if (!lineIndexValid) return "";
+		search.lineNumberHints[lineIndex] = search.doc->indexOf(search.lines[lineIndex], search.lineNumberHints[lineIndex]);
+		if (search.lineNumberHints[lineIndex] < 0) return "";
+		QDocumentLine ln = search.doc->line(search.lineNumberHints[lineIndex]);
+		if (role==Qt::DisplayRole) {
+			return prepareResultText(ln.text());
+		} else {  // tooltip role
+			return prepareReplacedText(ln.text());
+		}
+	}
+    return QVariant();
+}
+
+QVariant SearchResultModel::dataForSearchResult(const SearchInfo &search, int role) const {
+	switch (role) {
+	case Qt::ToolTipRole:
+		return QVariant();
+	case Qt::CheckStateRole:
+	{
+		if(search.checked.isEmpty())
+			return QVariant();
+		bool state = search.checked.first();
+		int cnt = search.checked.count(state);
+		if (cnt==search.checked.size()) {
+			return state ? Qt::Checked : Qt::Unchecked;
+		}else{
+			return Qt::PartiallyChecked;
+		}
+	}
+	case Qt::DisplayRole:
+		return (search.doc ? QDir::toNativeSeparators(search.doc->getFileName()) : tr("File closed")) + QString(" (%1)").arg(search.lines.size());
+	}
+	return QVariant();
 }
 
 QVariant SearchResultModel::data(const QModelIndex &index, int role) const {
 	if (!index.isValid()) return QVariant();
-	//if (index.row() >= log.count() || index.row() < 0) return QVariant();
-    //if (role == Qt::ToolTipRole) return tr("Click to jump to the line");
+	if (role != Qt::DisplayRole && role != Qt::CheckStateRole && role != Qt::ToolTipRole && role != LineNumberRole) return QVariant();
+	if (role == Qt::CheckStateRole && !mAllowPartialSelection) return QVariant();
 
-    if (role != Qt::DisplayRole && role != Qt::CheckStateRole && role != Qt::ToolTipRole) return QVariant();
-
-	int i=index.internalId();
-	int searchIndex = (i>>16)-1;
+	int iid = index.internalId();
+	int searchIndex = searchIndexFromIid(iid);
 	if (searchIndex < 0 || searchIndex >= m_searches.size()) return QVariant();
 	const SearchInfo& search = m_searches.at(searchIndex); 
-	if(i&(1<<15)){
-		if (!search.doc) return QVariant();
-		int lineIndex = index.row();
-        if (lineIndex < 0 || lineIndex > search.lines.size() || lineIndex > search.lineNumberHints.size()){
-            if(role==Qt::CheckStateRole)
-                return QVariant();
-            return "";
-        }
-        if(role==Qt::CheckStateRole){
-            return (search.checked.value(lineIndex,true) ? Qt::Checked : Qt::Unchecked);
-        }
-
-		search.lineNumberHints[lineIndex] = search.doc->indexOf(search.lines[lineIndex], search.lineNumberHints[lineIndex]);
-        if(search.lineNumberHints[lineIndex] < 0) {
-            return "";
-        }
-		QDocumentLine ln = search.doc->line(search.lineNumberHints[lineIndex]);
-        QString temp;
-        if(role==Qt::DisplayRole){
-            temp=QString("Line %1: ").arg(search.lineNumberHints[lineIndex]+1)+prepareResultText(ln.text());
-        }else{
-            // tooltip role
-            temp=prepareReplacedText(ln.text());
-        }
-
-        return temp;
+	if (iidIsResultEntry(iid)) {
+		return dataForResultEntry(search, index.row(), role);
 	} else {
-        if(role==Qt::ToolTipRole)
-            return QVariant();
-        if(role==Qt::CheckStateRole){
-            if(search.checked.isEmpty())
-                return QVariant();
-            bool state=search.checked.first();
-            int cnt=search.checked.count(state);
-            if(cnt==search.checked.size()){
-                return state ? Qt::Checked : Qt::Unchecked;
-            }else{
-                return Qt::PartiallyChecked;
-            }
-        }
-        REQUIRE_RET(index.row() == searchIndex, QVariant());
-		return (search.doc?search.doc->getFileName():tr("File closed")) + QString(" (%1)").arg(search.lines.size());
+		return dataForSearchResult(search, role);
 	}
 }
 
@@ -159,14 +227,14 @@ Qt::ItemFlags SearchResultModel::flags(const QModelIndex &index) const
 
 bool SearchResultModel::setData(const QModelIndex &index, const QVariant &value, int role)
 {
-    if (role != Qt::CheckStateRole )
+    if (role != Qt::CheckStateRole || !mAllowPartialSelection )
         return false;
 
-    int i=index.internalId();
-    int searchIndex = (i>>16)-1;
+    int iid = index.internalId();
+    int searchIndex = searchIndexFromIid(iid);
     if (searchIndex < 0 || searchIndex >= m_searches.size()) return false;
     SearchInfo& search = m_searches[searchIndex];
-    if(i&(1<<15)){
+    if (iidIsResultEntry(iid)) {
         if (!search.doc) return false;
         int lineIndex = index.row();
         if (lineIndex < 0 || lineIndex > search.lines.size() || lineIndex > search.lineNumberHints.size()){
@@ -182,9 +250,8 @@ bool SearchResultModel::setData(const QModelIndex &index, const QVariant &value,
         for(int l=0;l<search.checked.size();l++){
             search.checked.replace(l,state);
         }
-        int row=search.checked.size()-1;
-        int j=(i&0xFFFF0000)+(1<<15)+row;
-        QModelIndex endIndex=createIndex(row,0,j);
+        int lastRow = search.checked.size()-1;
+        QModelIndex endIndex=createIndex(lastRow, 0, makeResultEntryIid(iid, lastRow));
         emit dataChanged(index,endIndex);
     }
 
@@ -272,17 +339,17 @@ QList<QPair<int,int> > SearchResultModel::getSearchResults(const QString &text)
 }
 
 
+
 QDocument* SearchResultModel::getDocument(const QModelIndex &index){
-	int i=index.internalId();
-	i=(i>>16)-1;
+	int i = searchIndexFromIid(index.internalId());
 	if (i < 0 || i >= m_searches.size()) return 0;
 	if (!m_searches[i].doc) return 0;
 	return m_searches[i].doc;
 }
 int SearchResultModel::getLineNumber(const QModelIndex &index){
-	int i=index.internalId();
-	if (!(i&(1<<15))) return -1;
-	int searchIndex = (i>>16)-1;
+	int iid = index.internalId();
+	if (!iidIsResultEntry(iid)) return -1;
+	int searchIndex = searchIndexFromIid(iid);
 	if (searchIndex < 0 || searchIndex >= m_searches.size()) return -1;
 	const SearchInfo& search = m_searches.at(searchIndex); 
 	if (!search.doc) return -1;
