@@ -331,7 +331,7 @@ int WebPublishDialog:: nbpagesps(QString psfile) {
 	QString captured="0";
 	bool ok;
 	QFile f(psfile);
-	QRegExp rx("^\%\%Pages:\\s+(-?\\d+)");
+	QRegExp rx("^%%Pages:\\s+(-?\\d+)");
 	if (!f.open(QIODevice::ReadOnly)) {
 		fatalerror(psfile+" not found.");
 		return 0;
@@ -358,9 +358,9 @@ void WebPublishDialog::extractpage(QString psfile,int page) {
 	QString line;
 
 	QFile f(workdir+"/"+psfile);
-	QRegExp rxpage("^\%\%Page:\\s+(-?\\d+)");
-	QRegExp rxtrailer("^\%\%Trailer");
-	QRegExp rx("^\%\%Pages:\\s+(-?\\d+)");
+	QRegExp rxpage("^%%Page:\\s+(-?\\d+)");
+	QRegExp rxtrailer("^%%Trailer");
+	QRegExp rx("^%%Pages:\\s+(-?\\d+)");
 	if (!f.open(QIODevice::ReadOnly)) {
 		fatalerror(psfile+" not found.");
 		return;
@@ -378,12 +378,12 @@ void WebPublishDialog::extractpage(QString psfile,int page) {
 				if (rxpage.indexIn(line)>-1) {
 					int numpage=rxpage.cap(1).toInt();
 					if (numpage==page) {
-						line="\%\%Page: 1 1";
+						line="%%Page: 1 1";
 						go=true;
 					} else go=false;
 				}
 				if (rxtrailer.indexIn(line)>-1) go=true;
-				if (rx.indexIn(line)>-1) line="\%\%Pages: 1 0";
+				if (rx.indexIn(line)>-1) line="%%Pages: 1 0";
 				if (go) outts << line+"\n";
 			}
 			outf.close();
